#
# spec file for package bluefish
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bluefish
Version:        2.2.14
Release:        1.5
Summary:        A feature-Rich HTML Editor
License:        GPL-3.0-or-later
URL:            https://bluefish.openoffice.nl/
Source0:        https://www.bennewitz.com/bluefish/stable/source/%{name}-%{version}.tar.bz2
Source1:        https://www.bennewitz.com/bluefish/stable/source/%{name}-%{version}.tar.bz2.sig
Source2:        %{name}.keyring
# PATCH-FIX-OPENSUSE remove-python-class-shebang.patch - Remove unneeded shebang from python class files.
Patch0:         remove-python-class-shebang.patch
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  intltool
BuildRequires:  jing
BuildRequires:  man
BuildRequires:  pkgconfig
BuildRequires:  sgml-skel
BuildRequires:  tidy
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.24
BuildRequires:  pkgconfig(glib-2.0) >= 2.24
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.24
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.2.2
BuildRequires:  pkgconfig(gucharmap-2.90)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(python3)
Requires:       sgml-skel
Recommends:     libxml2-tools
Recommends:     make
Provides:       bluefish-unstable = %{version}-%{release}
Obsoletes:      bluefish-unstable < 2.2.3

%description
Bluefish is a HTML editor designed for the experienced Web designer
(supports HTML, PHP, Java, Perl, Python, Ruby, C, Pascal and more).

It is based on Gtk+.

%prep
%autosetup -p1

%build
# avoid aliasing warnings
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure  --with-icon-path=%{_datadir}/pixmaps \
            --disable-update-databases \
            --disable-xml-catalog-update \
            --enable-python
%make_build bflangsampledir="%{_docdir}/%{name}"

%install
%make_install \
             bflangsampledir="%{_docdir}/%{name}" \
             UPDATE_DESKTOP=echo \
             UPDATE_MIME=echo

%suse_update_desktop_file -r bluefish Application Network WebDevelopment GNOME
%fdupes %{buildroot}%{_datadir}

%find_lang bluefish
%find_lang bluefish_plugin_about
%find_lang bluefish_plugin_charmap
%find_lang bluefish_plugin_entities
%find_lang bluefish_plugin_htmlbar
%find_lang bluefish_plugin_infbrowser
%find_lang bluefish_plugin_snippets
%find_lang bluefish_plugin_zencoding
cat bluefish*.lang >> all.lang

%post
if [ -x %{_bindir}/xmlcatalog ]; then
	%{_bindir}/xmlcatalog --noout --add \
         'delegateURI' \
         'http://bluefish.openoffice.nl/ns/bflang/2.0/' \
         '%{_datadir}/xml/bluefish' \
         '%{_sysconfdir}/xml/catalog' || :
fi

%preun
if [ -x %{_bindir}/xmlcatalog ]; then
	%{_bindir}/xmlcatalog --noout --del \
         'http://bluefish.openoffice.nl/ns/bflang/2.0/' \
         '%{_sysconfdir}/xml/catalog' || :
fi

%files -f all.lang
%license COPYING
%doc AUTHORS README TODO
%{_docdir}/%{name}
%{_mandir}/man1/bluefish.1%{?ext_man}
%dir %{_datadir}/xml/bluefish
%dir %{_datadir}/xml/bluefish/2.0
%{_libdir}/%{name}
%{_bindir}/bluefish
%{_datadir}/bluefish
%{_datadir}/pixmaps/*bluefish*.png
%{_datadir}/applications/bluefish*.desktop
%{_datadir}/xml/bluefish/2.0/bflang2.rng
%{_datadir}/xml/bluefish/catalog.xml
%{_datadir}/icons/hicolor/*/*/*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/bluefish.appdata.xml
%{_datadir}/mime/packages/%{name}.xml

%changelog
* Sat Jun 10 2023 Dave Plater <davejplater@gmail.com>
- Update to 2.2.14
- Upstream changes:
  * Bluefish 2.2.14 fixes three bugs that in certain situations
  could lead to a segfault. One bug when deleting backup files on
  close.
  * The third bug when the CSS language file was loaded on a 32bit
  system. It furthermore fixes zencoding functionality with python3.
  It also adds an option to store the scope of the search dialog to
  the session or project (this was removed in 2.2.12 because of a
  bug-report). It furthermore improves the speed of the bookmarks
  code. The build infrastructure was also slightly modernised,
  intltool is no longer used.
* Thu May 18 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.2.13:
  * CSS syntax support has been greatly improved.
  * some fixes and some very minor bugs squashed
  * some minor improvements for the syntax highlighting in a few
    other languages, most notably python.
* Tue Jun 15 2021 Steve Kowalik <steven.kowalik@suse.com>
- Refresh remove-python-class-shebang.patch to remove a requirement of
  /usr/bin/python
- Switch BuildRequires for pkgconfig(python3) to link against it instead
* Tue Feb 23 2021 Dirk Müller <dmueller@suse.com>
- switch to non-deprecated enchant-2 library
* Fri Nov 20 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.2.12
  * fix for a crash in simple search
  * Python 3 compatibility has been further improved
  * Encoding detection in python files has been improved.
  * Triple click now selects the line.
  * Several programming languages have improved syntax highlighting
  * Bluefish now works fine with Enchant2 for spell checking.
* Sun Aug 23 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 2.2.11
  * Bluefish 2.2.11 is a minor maintenance release and minor feature release.
  * The only exception to that is the python 3 compatibility which is a major
    change. If you compile Bluefish with python 3, you might experience new
    bugs.
  * There are various minor changes as well.
  * Double click selection has been improved (for example selecting a function
    name that has underscores), and is now configurable per language.
  * Bluefish now has a feature to fill a line with spaces up to a mouse click,
    so you can start typing in any position on the screen (with a fixed width
    font).
  * A crash when running very large replace actions on disk on many files has
    been fixed.
  * Search and replace now ignores backup files by default.
  * Cursor highlighting and line highlighting have been fixed for a rare bug.
  * A small new feature has been added, to insert output from an external
    command in the current cursor position.
  * Many language files have seen updates, most notably CSS, Python and HTML.
  * A data loss bug - when an unknown encoding was selected - was fixed, the
    fallback is now to save as UTF-8.
  * A bug when saving with unknown characters in the filename has also been
    fixed.
  * Printing has been improved such as printing in landscape.
  * Some small tweaks to the UI have been implemented. For example you can now
    search in files in the filebrowser (right click a directory). Search
    results can now be shown in the output pane.
  * The current identifier can be selected using <shift><control><i>.
  * Last there various fixes when Bluefish is run on top of Wayland.
- Update gpgkeyring to correct for source validation
- Refresh patch remove-python-class-shebang.patch
- Remove in %%post since they are not needed anymore (triggers)
  * %%mime_database_post
  * %%desktop_database_post
- Remove in %%postun since they are not needed anymore (triggers)
  * %%mime_database_postun
  * %%desktop_database_postun
- Run spec-cleaner
  * Remove rpm groups
  * use make macros
* Tue Nov 28 2017 zaitor@opensuse.org
- Drop obsolete and unused BuildRequires, not needed after the
  switch to gtk3: pkgconfig(libglade-2.0),
  pkgconfig(libgnomeprint-2.2) and pkgconfig(libgnomeprintui-2.2)
  (boo#1067727).
- Align with what configure looks for:
  Drop enchant-devel and gtk3-devel BuildRequires.
  Add pkgconfig(gtk+-3.0), pkgconfig(gdk-3.0), pkgconfig(glib-2.0),
  pkgconfig(gmodule-2.0), pkgconfig(gobject-2.0), pkgconfig(pango),
  pkgconfig(gdk-pixbuf-2.0), pkgconfig(gio-unix-2.0),
  pkgconfig(gthread-2.0), pkgconfig(libxml-2.0) and
  pkgconfig(enchant) BuildRequires.
* Wed Jun 21 2017 tchvatal@suse.com
- Remove aspell and rely on enchant for spellcheck
  * This means the bluefish will use hunspell now
* Thu Mar 23 2017 rpm@fthiessen.de
- Update to version 2.2.10
  * Various language files have been improved
  * Various fixes for newer gtk versions and for gtk on wayland
  * New feature: Possibility to import/export syntax color styles,
    included are styles for a light and a dark theme.
  * Fixes for a few rare crashes.
  * Fixes incompatibility with Gtk 3.20.
  * Some small dialogs have been improved.
  * Some user interface parts have been polished.
  * Fixes a few serious but rarely occurring bugs.
  * Options defined in the language definition files
    are now translated.
  * Various default settings have been improved, most notably the
    command to launch Firefox for preview.
  * The looks on newer gtk versions have been restored.
  * CSS can now be compressed and decompressed.
  * Character encoding detection has been improved.
  * Auto-completion for HTML attributes has been improved.
  * The SASS style language has been added.
- Removed upstream merged fix_ptr_from_int.patch
- Added keyring / signature file for verification
- Added remove-python-class-shebang.patch to remove shebang from
  python class files (this ones get never executed as scripts).
* Wed Mar  8 2017 sfalken@opensuse.org
- Edited %%files section to clear unpackaged files builderror
  in openSUSE:Factory
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 2.2.7:
    Bluefish 2.2.7 is mostly a bug fix release. It fixes rare
    crashes in the autocompletion, the filebrowser, the htmlbar
    plugin preferences, and in file-load-cancel, fixes a rare case
    of broken syntax highlighting after multiple search/replace
    actions.
  * It furthermore displays better error/warning output when
    parsing language files.
  * It also finally fixes javascript regex syntax highlighting.
  * The loading of files with corrupt encoding has been improved,
    and project loading over sftp has been improved.
  * Various HTML5 tags have been added, and HTML5 is the default
    now for php, cfml and other languages that can include html
    syntax.
  * Saving and loading of UTF-16 encoded files was broken and has
    been fixes.
  * Various languages have better support, such as javascript, css,
    html, pascal/deplhi, and html has improved autocompletion.
  * On OSX the keys for tab switching no longer confict with some
    keyboard layouts, and behavior at shutdown was improved.
  * The upload/download feature has a new option to ignore backup
    files.
  * The home/end keys now work better on wrapped tekst.
  * And finally the search and replace dialog correctly shows the
    number of results when searching in files on disk.
- point the source URL to the master download server
- add fix_ptr_from_int.patch: fix pointer from integer assignment,
  already upstream
- avoid aliasing warnings: add -fno-strict-aliasing to CFLAGS
* Wed Jun 25 2014 lars@linux-schulserver.de
- update to 2.2.6:
  + mostly a bug fix release. This release fixes a critical bug
    (segfault) in filebrowser that could be triggered if the root
    directory was set as basedir.
  + It also has a fix for a specific CSS-in-HTML-tag highlighting issue.
  + The filter code furthermore caused a segfault if the command did not exist. T
  + Next to these bugs many small issues have been resolved.
  + Various language files have small improvements, most notably C,
    Javascript and CSS.
  + Several translations have been updated.
  + A corner case for a new document from a template that does not exist
    was fixed.
  + The "open" submenu now opens SVG files from the filebrowser instead
    of inserting an image tag.
  +  The included cssmin and jsbeatify have been updated.
  + A syntax scanning issue when replacing large chunks of text was
    fixed.
  + the "Report bug" link was broken,
  + a new "conditional" option to the language file that makes re-using
    certain blocks of language files easier was added,
  +  and error reporting in outputbox was improved.
- recommend make and libxml2-tools (xmllint) for easier programming
* Tue Feb 11 2014 lars@linux-schulserver.de
- update to 2.2.5:
  + The syntax scanning engine is faster after small changes to the text.
  + The filebrowser is also much faster with less memory usage, with
    various fixes and new features.
  + Projects now store the active document and active line numbers.
  + Indenting is improved in auto-completion and the smart indenting.
  + Bookmarks and paste special also have been improved.
  + Furthermore almost all syntax highlighting has been improved, most
    notable jquery in javascript, HTML5, and HTML5 in PHP files.
  + There are also many bug fixes, such as in wrap text on right margin,
    in the replace engine, the jsmin licence, the split lines feature,
    the auto-recovery and many obscure bugs.
* Tue Feb 12 2013 lars@linux-schulserver.de
- update to 2.2.4:
  + minor bugfix release
  + various fixes for the tab-width on gtk 3.6
  + improved auto-completion popup speed
  + more simple search options
  + paste improvements (to paste for example images from Libreoffice)
  + pylint, cssmin, jsmin, csstidy and php_beautifier integration
  + various language syntax definition files have also been improved
* Thu Jan 17 2013 cfarrell@suse.com
- license update: GPL-3.0+
  See the COPYING file and the majority of the source code file headers
* Sun Oct  7 2012 lars@linux-schulserver.de
- update to 2.2.3:
  + new feature: Zencoding support
  + works with gtk-3
  + faster syntax scanner
  + new search and replace function
  + support for new languages added: Google Go, Vala and Ada
  + some shortcut key combinations were added.
- small specfile cleanup
* Sun Sep 18 2011 lars@linux-schulserver.de
- update to 2.0.3:
  + improves syntax highlighting performance
  + improves performance when scrolling in large files
  + It adds a couple of features such as:
    a split view feature, Clojure syntax, Wordpress syntax,
    Pascal syntax, jQuery syntax, Processing syntax and R syntax
  + Various features have improved
  + a "jump to reference" feature has been added to quickly open
    a referenced filename
  + Finally, two new translations are added: Nynorsk and Hungarian
* Sat Jul 31 2010 lars@linux-schulserver.de
- update to 2.0.1:
  + minor bugfix and minor feature enhancement release
  + Enhancements include improved spell checking,
  + right margin display,
  + improved indenting functionality,
  + and CFML (cold fusion) support.
  + Bugfixes include fixes in a couple of HTML tag dialogs and
    two exotic segfault fixes.
* Fri May 14 2010 lars@linux-schulserver.de
- provide/obsolete older bluefish-unstable versions
* Sun May  9 2010 lars@linux-schulserver.de
- update to 2.0
- fix BuildRequires
- enable python and libgnomeui
- remove macros for old openSUSE versions
* Mon Sep 22 2008 lars@linux-schulserver.de
- moved to Education base repository
* Tue Jul 17 2007 lrupp@suse.de
- use /usr for builds > openSUSE 10.2
- Update to 1.0.7:
  + Updated translations: Finnish, French, German, Japanese,
    Norwegian, Polish, Swedish
  + Fixes Tcl highlighting
  + Fixes a bug when trying to save a file with a new install and
    a file has never been opened or a project is not open.
    Closes Bluefish bug #360401.
  + Fix a bug where Bluefish would crash when deleting
    multiple bookmarks.
  + Fix a bookmark memory leak
  + README: more complete README
  + Data filetypes: adds the .pm extension for Perl files.
    Closes Bluefish bug #343569.
  + Highlighting: small fix to XML highlighting (adding general
    support for namespaces). Highlight numbers in Java.
  + Adds XTHTM 1.1 DOCTYPE in creators. Closes Bluefish bug #338586
  + Fixes a bug in smart cursor positioning.
  + Fixes a bug where the old file was deleted before the new file
    was saved successfully.
  + Removes redundant show hidden checkbox from file chooser dialog.
    Closes Bluefish bug #316298
  + Fixes Definition list formatting
  + Fixes a bug where the backup file was not deleted after
    renaming it. Closes Bluefish bug #324788.
  + Fixes a critical bug where Bluefish crashed when closing and
    saving a project. Closes Bluefish bug #330544.
  + Fixes a critical bug where Bluefish crashed when pressing the
    Esc key in the Search:no match found dialog.
    Closes Bluefish bug #337739
  + Fixes a bug where undoing did not behave correctly for text
    pasted from the clipboard over other text.
    Closes Bluefish bug #340262.
  + Fixes a bug in python syntax highlighting.
    Closes Bluefish bug #349662.
  + Fixes a critical bug where Bluefish crashed when pressing the
    green info dialog button. Closes Bluefish bug #349743
  + ... (see NEWS file for more Changes)
* Tue Sep  5 2006 aj@suse.de
- Cleanup BuildRequires.
* Mon May 22 2006 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Don't strip binaries.
* Fri Feb 24 2006 sbrabec@suse.cz
- Improved Categories.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 snbarth@suse.de
- Fixed file list and mime update which is now in %%post and %%postun
* Wed Dec 14 2005 ro@suse.de
- mime file ends up in /usr/share/mime now
* Tue Aug  2 2005 snbarth@suse.de
- update to version 1.0.2
* Fri Jan 14 2005 snbarth@suse.de
- update to version 1.0
- new file list
- new patch for no -> nb rename
* Tue Oct 26 2004 ro@suse.de
- locale rename: no -> nb
* Tue Feb 24 2004 ro@suse.de
- neededforbuild: "weblint" -> "tidy"
* Mon Feb 23 2004 adrian@suse.de
- fix multiple menu entries
* Sun Feb 15 2004 ro@suse.de
- cleanup neededforbuild
- use buildroot
- build as user
* Thu Feb 12 2004 ro@suse.de
- added gconf2 to neededforbuild
* Wed Jan 14 2004 snbarth@suse.de
- update to version 0.12
* Mon Sep  1 2003 adrian@suse.de
- fix Category
* Sat Aug 16 2003 adrian@suse.de
- add Categories
* Thu Jun 12 2003 coolo@suse.de
- use %%find_lang
* Wed May 21 2003 coolo@suse.de
- don't install into man1/man1
* Tue Jan 14 2003 nadvornik@suse.cz
- fixed multi-line string literals
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Fri Jun 21 2002 ro@suse.de
- run suse_update_config
* Wed May  1 2002 kukuk@suse.de
- Remove superfluous libmpeg from neededforbuild
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Dec 17 2001 snbarth@suse.de
- update to version 0.7
* Mon Jun 18 2001 schwab@suse.de
- Fix broken use of token concatentation.
* Mon May 14 2001 snbarth@suse.de
- Took netscape out of needed for build
* Thu Mar  8 2001 uli@suse.de
- fixed to build
* Thu Dec 28 2000 egger@suse.de
- Also install icon for GNOME desktop.
* Thu Dec 28 2000 egger@suse.de
- Updated to version 0.6. Lots of bugfixes.
- Use BuildRoot.
- Cleaned up specfile.
- Use RPM_OPT_FLAGS.
* Wed Nov 15 2000 snbarth@suse.de
- update to new version 0.5
* Sun Nov  5 2000 ro@suse.de
- fixed invalid group: X11/GNOME/Utilities
* Sun Nov  5 2000 egger@suse.de
- Changed #neededforbuild line to new packagenames.
* Tue Sep  5 2000 snbarth@suse.de
- new version 0.4, also took over maintenance
* Wed Feb  2 2000 freitag@suse.de
- new version 0.3.5
* Sat Oct 23 1999 freitag@suse.de
- new version 0.3.3a
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jul 14 1999 ray@suse.de
- new package
